Documentation
¶
Index ¶
- func NewClusterServiceBrokerInformer(client clientset.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewClusterServiceClassInformer(client clientset.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewClusterServicePlanInformer(client clientset.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredClusterServiceBrokerInformer(client clientset.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredClusterServiceClassInformer(client clientset.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredClusterServicePlanInformer(client clientset.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredServiceBindingInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredServiceBrokerInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredServiceClassInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredServiceInstanceInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredServicePlanInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewServiceBindingInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewServiceBrokerInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewServiceClassInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewServiceInstanceInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewServicePlanInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type ClusterServiceBrokerInformer
- type ClusterServiceClassInformer
- type ClusterServicePlanInformer
- type Interface
- type ServiceBindingInformer
- type ServiceBrokerInformer
- type ServiceClassInformer
- type ServiceInstanceInformer
- type ServicePlanInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewClusterServiceBrokerInformer ¶
func NewClusterServiceBrokerInformer(client clientset.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewClusterServiceBrokerInformer constructs a new informer for ClusterServiceBroker type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewClusterServiceClassInformer ¶
func NewClusterServiceClassInformer(client clientset.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewClusterServiceClassInformer constructs a new informer for ClusterServiceClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewClusterServicePlanInformer ¶
func NewClusterServicePlanInformer(client clientset.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewClusterServicePlanInformer constructs a new informer for ClusterServicePlan type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredClusterServiceBrokerInformer ¶ added in v0.1.31
func NewFilteredClusterServiceBrokerInformer(client clientset.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredClusterServiceBrokerInformer constructs a new informer for ClusterServiceBroker type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredClusterServiceClassInformer ¶ added in v0.1.31
func NewFilteredClusterServiceClassInformer(client clientset.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredClusterServiceClassInformer constructs a new informer for ClusterServiceClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredClusterServicePlanInformer ¶ added in v0.1.31
func NewFilteredClusterServicePlanInformer(client clientset.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredClusterServicePlanInformer constructs a new informer for ClusterServicePlan type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredServiceBindingInformer ¶ added in v0.1.31
func NewFilteredServiceBindingInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredServiceBindingInformer constructs a new informer for ServiceBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredServiceBrokerInformer ¶ added in v0.1.31
func NewFilteredServiceBrokerInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredServiceBrokerInformer constructs a new informer for ServiceBroker type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredServiceClassInformer ¶ added in v0.1.31
func NewFilteredServiceClassInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredServiceClassInformer constructs a new informer for ServiceClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredServiceInstanceInformer ¶ added in v0.1.31
func NewFilteredServiceInstanceInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredServiceInstanceInformer constructs a new informer for ServiceInstance type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredServicePlanInformer ¶ added in v0.1.31
func NewFilteredServicePlanInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredServicePlanInformer constructs a new informer for ServicePlan type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewServiceBindingInformer ¶
func NewServiceBindingInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewServiceBindingInformer constructs a new informer for ServiceBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewServiceBrokerInformer ¶ added in v0.1.31
func NewServiceBrokerInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewServiceBrokerInformer constructs a new informer for ServiceBroker type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewServiceClassInformer ¶ added in v0.1.31
func NewServiceClassInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewServiceClassInformer constructs a new informer for ServiceClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewServiceInstanceInformer ¶
func NewServiceInstanceInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewServiceInstanceInformer constructs a new informer for ServiceInstance type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewServicePlanInformer ¶ added in v0.1.31
func NewServicePlanInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewServicePlanInformer constructs a new informer for ServicePlan type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type ClusterServiceBrokerInformer ¶
type ClusterServiceBrokerInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1beta1.ClusterServiceBrokerLister
}
ClusterServiceBrokerInformer provides access to a shared informer and lister for ClusterServiceBrokers.
type ClusterServiceClassInformer ¶
type ClusterServiceClassInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1beta1.ClusterServiceClassLister
}
ClusterServiceClassInformer provides access to a shared informer and lister for ClusterServiceClasses.
type ClusterServicePlanInformer ¶
type ClusterServicePlanInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1beta1.ClusterServicePlanLister
}
ClusterServicePlanInformer provides access to a shared informer and lister for ClusterServicePlans.
type Interface ¶
type Interface interface {
// ClusterServiceBrokers returns a ClusterServiceBrokerInformer.
ClusterServiceBrokers() ClusterServiceBrokerInformer
// ClusterServiceClasses returns a ClusterServiceClassInformer.
ClusterServiceClasses() ClusterServiceClassInformer
// ClusterServicePlans returns a ClusterServicePlanInformer.
ClusterServicePlans() ClusterServicePlanInformer
// ServiceBindings returns a ServiceBindingInformer.
ServiceBindings() ServiceBindingInformer
// ServiceBrokers returns a ServiceBrokerInformer.
ServiceBrokers() ServiceBrokerInformer
// ServiceClasses returns a ServiceClassInformer.
ServiceClasses() ServiceClassInformer
// ServiceInstances returns a ServiceInstanceInformer.
ServiceInstances() ServiceInstanceInformer
// ServicePlans returns a ServicePlanInformer.
ServicePlans() ServicePlanInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type ServiceBindingInformer ¶
type ServiceBindingInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1beta1.ServiceBindingLister
}
ServiceBindingInformer provides access to a shared informer and lister for ServiceBindings.
type ServiceBrokerInformer ¶ added in v0.1.31
type ServiceBrokerInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1beta1.ServiceBrokerLister
}
ServiceBrokerInformer provides access to a shared informer and lister for ServiceBrokers.
type ServiceClassInformer ¶ added in v0.1.31
type ServiceClassInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1beta1.ServiceClassLister
}
ServiceClassInformer provides access to a shared informer and lister for ServiceClasses.
type ServiceInstanceInformer ¶
type ServiceInstanceInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1beta1.ServiceInstanceLister
}
ServiceInstanceInformer provides access to a shared informer and lister for ServiceInstances.
type ServicePlanInformer ¶ added in v0.1.31
type ServicePlanInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1beta1.ServicePlanLister
}
ServicePlanInformer provides access to a shared informer and lister for ServicePlans.